#include <stdio.h>


int main(int argc, char **argv){
	int i=0;
	/* Verifichiamo che vi siano almeno 2 argomenti da confrontare  */
	if (argc<3) {
		printf("Ci sono meno di 2 argomenti!\n");
		return -1;
	}
	/* ad ogni iterazione, verifica che il carattere i-esimo sia uguale per le due stringhe */
	while(argv[1][i]!='\0' && argv[2][i]!='\0' ) {
		if (argv[1][i] != argv[2][i]) {
			printf("Le due stringhe sono diverse!\n");
			return 0;
		}
		i=i+1;
	}
	/* i ha come valore l'indice del carattere terminatore nella stringa piu' corta! */
	/* verifica che entrambe le stringhe siano terminate */
	if (argv[1][i]==argv[2][i]) {
		printf("Le due stringhe sono uguali!\n");
	} else {
		printf("Le due stringhe sono diverse!\n");
	}
	return 0;
} 
