#include <stdio.h>

/* Il programma riordina i caratteri della prima 
   stringa argomento in ordine alfabetico */
int main(int argc, char **argv){
	char sorted[128];
	int length=0;
	int i=0, j=0, k=0;
	if (argc<2) return -1;
	while(argv[1][length]!='\0') length++;
	for(i=0; i<length; i++){
		char current=argv[1][i];
		/* cerca la posizione di current nell'array sorted */
		for(j=0; j<i && current>sorted[j]; j++);
		/* j indica la posizione in sorted 
		   in cui inserire current */
		for(k=i; k>j; k--){
			sorted[k]=sorted[k-1];
		}
		sorted[j]=current;
	}
	sorted[length]='\0';

	/*
	           01234
		   j  k
	sorted	-> hk ll
	argv[1] -> khllg\0
		       i	
	*/
	
	printf("%s\n", sorted);
	return 0;
}
