#include <stdio.h>

/* Il programma verifica se il suo primo
 argomento e' o meno una stringa palindroma */
int main(int argc, char **argv){
	int i,j;
	int length=0;
	/* verifica la presenza dell'argomento */
	if (argc<2) return -1;
	/* calcola la lunghezza della stringa */	
	while(argv[1][length]!='\0') length++;
	/*
	i=0 -->
            <-- j=length-1
	
	  i     	
	anna
         j
	*/
	for(i=0, j=length-1; i<j; i++,j--) {
		if (argv[1][i]!=argv[1][j]) {
			printf("La stringa non e' palindroma!\n");
			return 0;
		}
	}
	printf("La stringa e' palindroma!\n");
	return 0;
}
