#include <stdio.h>

int main(int argc, char **argv){
	char rev[128];
	int length=0;
	int i;
	/* deve esserci almeno un argomento! */
	if (argc<2){
		printf("Nessun argomento\n");
		return -1;
	}
	/* l'argomento argv[1] deve avere meno di 128 caratteri */
	/* calcola la lunghezza della stringa */
	while(argv[1][length]!='\0') {
		length=length+1;
	}
	/* se la lunghezza e' >= 128, termina l'esecuzione */
	if (length>=128) {
		printf("La stringa e' troppo lunga!\n");
		return -2;
	}
	/* length-1==i 
	for(i=length-1; i>=0; i--){
		rev[length-1-i] = argv[1][i];
	} */
	for(i=0; i<length; i++){
		rev[i] = argv[1][length-1-i];
	}
	rev[length]='\0';
	printf("%s\n", rev);
	return 0;
}
